import { page } from "./api";
import store from "./store";
import queryParamMixin from "./queryParamMixin";

export default {
  mixins: [queryParamMixin],
  props: {
    pageSize: {
      type: Number,
      required: false,
      default: 10,
    },
  },
  created() {
    store.commit("setPageSize", this.pageSize);
    store.commit("setPageIndex", 1);
    this.load();
  },
  methods: {
    reload() {
      store.commit("setPageIndex", 1);
      this.load();
    },
    load() {
      if (this.category == -1) return;
      this.loading = true;
      page(this.name, this.queryParam, this.size, this.index)
        .then((resp) => {
          this.data = resp.records;
          store.commit("setTotal", resp.total);
          this.$emit("done", resp);
        })
        .finally(() => (this.loading = false));
    },
  },
  computed: {
    index() {
      return store.getters.pageIndex;
    },
    size() {
      return store.getters.pageSize;
    },
  },
  watch: {
    index(n, o) {
      if (n !== o) {
        this.load();
      }
    },
  },
};
