export default {
  props: {
    name: {
      type: String,
      required: true,
    },
    query: {
      type: Array,
      required: false,
      default: () => [],
    },
    order: {
      type: String,
      required: false,
      default: "",
    },
    columns: {
      type: String,
      required: false,
      default: "",
    },
    category: {
      type: [Number, String],
      required: false,
      default: null,
    },
  },
  watch: {
    query() {
      this.reload();
    },
    order() {
      this.reload();
    },
    columns() {
      this.reload();
    },
    category() {
      this.reload();
    },
  },
  data() {
    return {
      data: [],
      loading: false,
    };
  },
  computed: {
    columnsParam() {
      return this.columns ? this.columns.split(",") : [];
    },
    orderParam() {
      if (this.order) {
        const orders = this.order.split(",");
        return orders.map((col) => {
          if (col.startsWith("-")) {
            col = col.slice(1);
            return {
              column: col,
              direction: "desc",
            };
          } else {
            return {
              column: col,
              direction: "asc",
            };
          }
        });
      } else {
        return [];
      }
    },
    queryParam() {
      const query = [...this.query];
      if (this.category)
        query.push({
          column: "category_id",
          value: this.category,
          operator: "=",
        });
      return {
        query: query,
        order: this.orderParam,
        columns: this.columnsParam,
      };
    },
  },
  render() {
    return this.$scopedSlots.default(this.data);
  },
};
